==> openshift-model-storageversionmigrator-5.11.1-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/MigrationConditionBuilder.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MigrationConditionBuilder extends io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionFluentImpl<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationCondition,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionBuilder>{
  public MigrationConditionBuilder() {
    this(false);
  }
  public MigrationConditionBuilder(java.lang.Boolean validationEnabled) {
    this(new MigrationCondition(), validationEnabled);
  }
  public MigrationConditionBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public MigrationConditionBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MigrationCondition(), validationEnabled);
  }
  public MigrationConditionBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionFluent<?> fluent,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationCondition instance) {
    this(fluent, instance, false);
  }
  public MigrationConditionBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionFluent<?> fluent,io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MigrationConditionBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationCondition instance) {
    this(instance,false);
  }
  public MigrationConditionBuilder(io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationCondition instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationConditionFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1.MigrationCondition build() {
    MigrationCondition buildable = new MigrationCondition(fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MigrationConditionBuilder that = (MigrationConditionBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-storageversionmigrator-6.5.1-sources.jar: io/fabric8/openshift/api/model/storageversionmigrator/v1alpha1/MigrationConditionBuilder.java <==
package io.fabric8.openshift.api.model.storageversionmigrator.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MigrationConditionBuilder extends MigrationConditionFluentImpl<MigrationConditionBuilder> implements VisitableBuilder<MigrationCondition,MigrationConditionBuilder>{
  public MigrationConditionBuilder() {
    this(false);
  }
  public MigrationConditionBuilder(Boolean validationEnabled) {
    this(new MigrationCondition(), validationEnabled);
  }
  public MigrationConditionBuilder(MigrationConditionFluent<?> fluent) {
    this(fluent, false);
  }
  public MigrationConditionBuilder(MigrationConditionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MigrationCondition(), validationEnabled);
  }
  public MigrationConditionBuilder(MigrationConditionFluent<?> fluent,MigrationCondition instance) {
    this(fluent, instance, false);
  }
  public MigrationConditionBuilder(MigrationConditionFluent<?> fluent,MigrationCondition instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withLastUpdateTime(instance.getLastUpdateTime()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withReason(instance.getReason()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MigrationConditionBuilder(MigrationCondition instance) {
    this(instance,false);
  }
  public MigrationConditionBuilder(MigrationCondition instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withLastUpdateTime(instance.getLastUpdateTime()); 
    this.withMessage(instance.getMessage()); 
    this.withReason(instance.getReason()); 
    this.withStatus(instance.getStatus()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MigrationConditionFluent<?> fluent;
  Boolean validationEnabled;
  public MigrationCondition build() {
    MigrationCondition buildable = new MigrationCondition(fluent.getLastUpdateTime(),fluent.getMessage(),fluent.getReason(),fluent.getStatus(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
